"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
Object.defineProperty(exports, "normalizeOptions", {
    enumerable: true,
    get: ()=>normalizeOptions
});
const _extends = require("@swc/helpers/lib/_extends.js").default;
const _interopRequireDefault = require("@swc/helpers/lib/_interop_require_default.js").default;
const _objectWithoutPropertiesLoose = require("@swc/helpers/lib/_object_without_properties_loose.js").default;
const _lodashGet = /*#__PURE__*/ _interopRequireDefault(require("lodash.get"));
const _path = /*#__PURE__*/ _interopRequireDefault(require("path"));
const _constants = require("../constants");
const defaultOptions = {
    compiler: 'tsc',
    disableDownloadingRemoteTypes: false,
    disableTypeCompilation: false,
    typescriptFolderName: _constants.TYPESCRIPT_FOLDER_NAME,
    typescriptCompiledFolderName: _constants.TYPESCRIPT_COMPILED_FOLDER_NAME,
    additionalFilesToCompile: []
};
const normalizeOptions = (options, compiler)=>{
    const webpackCompilerOptions = compiler.options;
    const { context , watchOptions  } = webpackCompilerOptions;
    const _ref = _extends({}, defaultOptions, options), { federationConfig , typescriptFolderName , typescriptCompiledFolderName  } = _ref, restOptions = _objectWithoutPropertiesLoose(_ref, [
        "federationConfig",
        "typescriptFolderName",
        "typescriptCompiledFolderName"
    ]);
    const federationFileName = federationConfig.filename;
    const distPath = (0, _lodashGet.default)(webpackCompilerOptions, 'devServer.static.directory') || (0, _lodashGet.default)(webpackCompilerOptions, 'output.path') || 'dist';
    const typesPath = federationFileName.substring(0, federationFileName.lastIndexOf('/'));
    const typesIndexJsonFilePath = _path.default.join(typesPath, _constants.TYPES_INDEX_JSON_FILE_NAME);
    const distDir = _path.default.join(distPath, typesPath, typescriptFolderName);
    const tsCompilerOptions = {
        declaration: true,
        emitDeclarationOnly: true,
        outDir: _path.default.join(distDir, `/${typescriptCompiledFolderName}/`),
        noEmit: false
    };
    const webpackPublicPath = webpackCompilerOptions.output.publicPath;
    const publicPath = typeof webpackPublicPath === 'string' ? webpackPublicPath === 'auto' ? '' : webpackPublicPath : '';
    const watchOptionsToIgnore = [
        _path.default.normalize(_path.default.join(context, typescriptFolderName))
    ];
    const ignoredWatchOptions = Array.isArray(watchOptions.ignored) ? [
        ...watchOptions.ignored,
        ...watchOptionsToIgnore
    ] : watchOptionsToIgnore;
    return _extends({}, restOptions, {
        distDir,
        publicPath,
        tsCompilerOptions,
        typesIndexJsonFileName: _constants.TYPES_INDEX_JSON_FILE_NAME,
        typesIndexJsonFilePath,
        typescriptFolderName,
        webpackCompilerOptions,
        ignoredWatchOptions
    });
};

//# sourceMappingURL=normalizeOptions.js.map